@@ -48,7 +48,14 @@ class FastQCManager:
 
             self.data = self.pull_data(self.module_name)
             self.write_reports()
-            self.switch_graph(module)
+
+            # For some reason graph generation doesn't work in terminal but does in PyCharm... can't figure this out.
+            # I know it is exclusively to do with sns.lineplot() (based on console output), but works fine in my IDE?
+            # With longer deadline, I think this could be fixed by altering code, but will probably take time.
+            try:
+                self.switch_graph(module)
+            except IndexError:
+                Log.warning("Graph cannot be made, this problem is recognised.")
 
         self.show_basic_statistics()
 
